package edu.lawrence.morecomponents

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.selection.selectable
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.AlertDialog
import androidx.compose.material3.Button
import androidx.compose.material3.Card
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.RadioButton
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateListOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.semantics.Role
import androidx.compose.ui.unit.dp
import androidx.compose.ui.window.Dialog

@Composable
fun DialogScreen(modifier : Modifier) {
    val done = remember { mutableStateOf(false) }
    val openAlert = remember { mutableStateOf(false) }
    val colors = listOf("Red","Green","Blue")
    val favoriteColor = remember { mutableStateOf(colors[0]) }
    val openDialog = remember { mutableStateOf(false) }

    Column(verticalArrangement = Arrangement.Center,horizontalAlignment = Alignment.CenterHorizontally, modifier = modifier.fillMaxSize().padding(10.dp)) {
        if(done.value) {
            Text("You did it.")
        } else {
            Button(onClick = { openAlert.value = true }) {
                Text("Do It!")
            }
        }
        if (openAlert.value) {
            AlertDialog(
                onDismissRequest = {
                    openAlert.value = false
                },
                title = { Text(text = "Are you sure?") },
                text = { Text(text = "Are you sure you want to do it?") },
                confirmButton = {
                    TextButton(onClick = {
                        openAlert.value = false
                        done.value = true
                    }) { Text("Confirm") }
                },
                dismissButton = {
                    TextButton(onClick = { openAlert.value = false }) { Text("Dismiss") }
                }
            )
        }
        Spacer(modifier = Modifier.height(20.dp))
        Text("Your favorite color is ${favoriteColor.value}.")
        Button(onClick = { openDialog.value = true }) {
            Text("Change it!")
        }
        if(openDialog.value) {
            DialogWithChoice(choices = colors,
                onConfirmation = {
                    favoriteColor.value = it
                    openDialog.value = false
                },
                onDismissRequest = {
                    openDialog.value = false
                })
        }
    }
}

@Composable
fun DialogWithChoice(
    choices: List<String>,
    onConfirmation: (String) -> Unit,
    onDismissRequest: () -> Unit
) {
    val selected = remember { mutableStateOf(choices[0]) }

    Dialog(onDismissRequest = { onDismissRequest() }) {
        // Draw a rectangle shape with rounded corners inside the dialog
        Card(
            modifier = Modifier.padding(16.dp),
            shape = RoundedCornerShape(16.dp),
        ) {
            Column(
                modifier = Modifier,
                verticalArrangement = Arrangement.Center
            ) {
                Text(
                    text = "Make a selection",
                    modifier = Modifier.padding(16.dp),
                )
                choices.forEach { choice ->
                    Row(
                        Modifier.selectable(
                            selected = (choice == selected.value),
                            onClick = { selected.value = choice },
                            role = Role.RadioButton
                        )
                            .padding(horizontal = 16.dp),
                        verticalAlignment = Alignment.CenterVertically
                    ) {
                        RadioButton(
                            selected = (choice == selected.value),
                            onClick = null
                        )
                        Text(
                            text = choice,
                            style = MaterialTheme.typography.bodyMedium,
                            modifier = Modifier.padding(start = 16.dp)
                        )
                    }
                }
                Row(
                    modifier = Modifier
                        .fillMaxWidth(),
                    horizontalArrangement = Arrangement.Center,
                ) {
                    TextButton(
                        onClick = { onDismissRequest() },
                        modifier = Modifier.padding(8.dp),
                    ) {
                        Text("Dismiss")
                    }
                    TextButton(
                        onClick = { onConfirmation(selected.value) },
                        modifier = Modifier.padding(8.dp),
                    ) {
                        Text("Confirm")
                    }
                }
            }
        }
    }
}