package edu.lawrence.morecomponents

import androidx.compose.foundation.background
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.selection.selectable
import androidx.compose.foundation.selection.selectableGroup
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.MoreVert
import androidx.compose.material3.Card
import androidx.compose.material3.DropdownMenu
import androidx.compose.material3.DropdownMenuItem
import androidx.compose.material3.Icon
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.RadioButton
import androidx.compose.material3.Switch
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.semantics.Role
import androidx.compose.ui.unit.dp

@Composable
fun FormScreen(modifier : Modifier) {
    val toggleState = remember { mutableStateOf(false) }
    val meals = listOf("Breakfast","Lunch","Dinner")
    val favoriteMeal = remember { mutableStateOf(meals[1]) }
    val colors = listOf("Red","Green","Blue")
    val favoriteColor = remember { mutableStateOf(colors[1])}

    Column(verticalArrangement = Arrangement.Center,horizontalAlignment = Alignment.CenterHorizontally, modifier = modifier.fillMaxSize().padding(10.dp)) {
        Card() {
            Column(modifier = Modifier.padding(10.dp)) {
                Row(
                    horizontalArrangement = Arrangement.Start,
                    verticalAlignment = Alignment.CenterVertically
                ) {
                    Text("Prefer this:")
                    Spacer(modifier = Modifier.width(10.dp))
                    Switch(
                        checked = toggleState.value,
                        onCheckedChange = { toggleState.value = it })
                }
                if (toggleState.value)
                    Text("You prefer this.")
                else
                    Text("You prefer that.")
            }
        }
        Spacer(modifier=Modifier.height(10.dp))
        Card() {
            Column(modifier = Modifier.padding(10.dp)) {
                Row(
                    horizontalArrangement = Arrangement.Start,
                    verticalAlignment = Alignment.CenterVertically,
                ) {
                    Text("What is your favorite meal?")
                    Spacer(modifier = Modifier.width(10.dp))
                    TextMenu(meals,meals[1],{favoriteMeal.value = it})
                }
                Text("Your favorite meal is ${favoriteMeal.value}.")
            }
        }
        Spacer(modifier=Modifier.height(10.dp))
        Card() {
            Column(Modifier.padding(10.dp).selectableGroup()) {
                Text("What is your favorite color?")
                colors.forEach { color ->
                    Row(
                        Modifier.selectable(
                                selected = (color == favoriteColor.value),
                                onClick = { favoriteColor.value = color },
                                role = Role.RadioButton
                            )
                            .padding(horizontal = 16.dp),
                        verticalAlignment = Alignment.CenterVertically
                    ) {
                        RadioButton(
                            selected = (color == favoriteColor.value),
                            onClick = null
                        )
                        Text(
                            text = color,
                            style = MaterialTheme.typography.bodyMedium,
                            modifier = Modifier.padding(start = 16.dp)
                        )
                    }
                }
                Text("You chose ${favoriteColor.value}.")
            }
        }

    }
}

@Composable
fun TextMenu(choices : List<String>,default : String,onChoice : (String)->Unit) {
    val expanded = remember { mutableStateOf(false) }
    val selected = remember { mutableStateOf(default) }
    Column() {
        Row(
            modifier = Modifier.background(color = MaterialTheme.colorScheme.background).padding(5.dp)
                .clickable(onClick = { expanded.value = !expanded.value })
        ) {
            Text(selected.value)
            Icon(
                imageVector = Icons.Default.MoreVert,
                contentDescription = "More"
            )
        }
        DropdownMenu(
            expanded = expanded.value,
            onDismissRequest = { expanded.value = false }
        ) {
            choices.forEach { choice ->
                DropdownMenuItem(text = { Text(choice) },
                    onClick = {
                        selected.value = choice
                        expanded.value = false
                        onChoice(choice)
                    })
            }
        }
    }
}