package edu.lawrence.morecomponents

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.AccountBox
import androidx.compose.material.icons.filled.Check
import androidx.compose.material.icons.filled.Edit
import androidx.compose.material3.BottomAppBar
import androidx.compose.material3.Icon
import androidx.compose.material3.IconButton
import androidx.compose.material3.Scaffold
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.ui.Modifier
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import edu.lawrence.morecomponents.ui.theme.MoreComponentsTheme

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()
        setContent {
            MoreComponentsTheme {
                TabApp()
            }
        }
    }
}

@Composable
fun TabApp() {
    val navController = rememberNavController()

    Scaffold(bottomBar = {
        BottomAppBar(
            actions = {
                IconButton(onClick = { navController.navigate("form") }) {
                    Icon(Icons.Filled.Edit,
                        contentDescription = "Form Demo")
                }
                IconButton(onClick = { navController.navigate("dialog") }) {
                    Icon(Icons.Filled.Check,
                        contentDescription = "Dialog Demo")
                }
                IconButton(onClick = { navController.navigate("photo")}) {
                    Icon(Icons.Filled.AccountBox,
                        contentDescription = "Photo Demo")
                }
            }
        )
    },
        modifier = Modifier.fillMaxSize()) { innerPadding ->
        NavHost(navController,startDestination="form") {
            composable(route="form") {
                FormScreen(modifier = Modifier.padding(innerPadding))
            }
            composable(route="dialog") {
                DialogScreen(modifier = Modifier.padding(innerPadding))
            }
            composable(route="photo") {
                PhotoScreen(modifier = Modifier.padding(innerPadding))
            }
        }
    }
}
